pycocoa.lazily.LazyImportError

Package pycocoa :: Module lazily :: Class LazyImportError |
[frames] | no frames]

# Class LazyImportError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                  exceptions.ImportError --+
                                           |
                                          LazyImportError

Raised if `lazy import` is not supported, disabled or failed.

Instance Methods
Inherited from `exceptions.ImportError`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`